@@ -36,32 +36,18 @@ class ParserMeta(type):
 
 
 class Parser(ArgumentParser, metaclass=ParserMeta):
-    """Subclass of Params to fit for pipen
+    """Subclass of Params to fit for pipen"""
 
-    Args:
-        pipeline_args_group: The group name to gather all the parameters on
-            help page
-        flatten_proc_args: Flatten process arguments to the top level
-    """
-    def __init__(
-        self,
-        *args,
-        pipeline_args_group: str = PIPELINE_ARGS_GROUP,
-        flatten_proc_args: bool | str = FLATTEN_PROC_ARGS,
-        **kwargs,
-    ) -> None:
+    def __init__(self, *args, **kwargs) -> None:
         """Constructor"""
         kwargs["add_help"] = "+"
         kwargs["fromfile_prefix_chars"] = "@"
         kwargs["usage"] = "%(prog)s [-h | -h+] [options]"
         super().__init__(*args, **kwargs)
 
-        self.flatten_proc_args = flatten_proc_args
+        self.flatten_proc_args: bool | str | None = None
         self._cli_args = None
-        self._pipeline_args_group = self.add_argument_group(
-            pipeline_args_group,
-            order=-99,
-        )
+        self._pipeline_args_group = None
         self._parsed = None
 
     def set_cli_args(self, args: Any) -> None:
@@ -82,6 +68,16 @@ class Parser(ArgumentParser, metaclass=ParserMeta):
 
     def init(self, pipen: Pipen) -> None:
         """Define arguments"""
+
+        self._pipeline_args_group = self.add_argument_group(
+            pipen._kwargs["plugin_opts"].get("args_group", PIPELINE_ARGS_GROUP),
+            order=-99,
+        )
+        self.flatten_proc_args = pipen._kwargs["plugin_opts"].get(
+            "args_flatten",
+            FLATTEN_PROC_ARGS,
+        )
+
         pipen.build_proc_relationships()
         if len(pipen.procs) > 1 and self.flatten_proc_args is True:
             raise ValueError(  # pragma: no cover
@@ -91,7 +87,7 @@ class Parser(ArgumentParser, metaclass=ParserMeta):
         if self.flatten_proc_args == "auto":
             self.flatten_proc_args = (
                 len(pipen.procs) == 1
-                and not getattr(pipen.procs[0], "__procgroup__", False)
+                and not pipen.procs[0].__meta__["procgroup"]
             )
 
         for arg, argopt in PIPEN_ARGS.items():
@@ -106,11 +102,11 @@ class Parser(ArgumentParser, metaclass=ParserMeta):
             if arg in ("scheduler_opts", "plugin_opts"):
                 if self.flatten_proc_args:
                     argopt["default"] = (
-                        Diot(pipen.config.get(arg, None) or {})
+                        Diot(pipen._kwargs.get(arg, None) or {})
                         | (getattr(pipen.procs[0], arg, None) or {})
                     )
                 else:
-                    argopt["default"] = pipen.config.get(arg, None) or {}
+                    argopt["default"] = pipen._kwargs.get(arg, None) or {}
 
             self._pipeline_args_group.add_argument(f"--{arg}", **argopt)
 
@@ -123,7 +119,7 @@ class Parser(ArgumentParser, metaclass=ParserMeta):
             )
         else:
             for i, proc in enumerate(pipen.procs):
-                in_procgroup = bool(getattr(proc, "__procgroup__", None))
+                in_procgroup = bool(proc.__meta__["procgroup"])
                 self._add_proc_args(
                     proc,
                     is_start=proc in pipen.starts and not in_procgroup,
@@ -158,15 +154,20 @@ class Parser(ArgumentParser, metaclass=ParserMeta):
                 "required",
                 "metavar",
                 "choices",
+                "type",
             )
         }
-        if "hide" in anno_attrs:
+        if "hidden" in anno_attrs:
             out["show"] = False
 
-        if "atype" in anno_attrs:
-            out["type"] = anno_attrs["atype"]
-        elif "type" in anno_attrs:
-            out["type"] = anno_attrs["type"]
+        # Add some shotcuts
+        if anno_attrs.get("ns") or anno_attrs.get("namespace"):
+            out.setdefault("action", "ns")
+        if anno_attrs.get("flag"):
+            out.setdefault("action", "store_true")
+        if anno_attrs.get("array") or anno_attrs.get("list"):
+            out.setdefault("action", "clear_extend")
+            out.setdefault("nargs", "+")
 
         typefun = None
         if out.get("type"):
@@ -199,8 +200,8 @@ class Parser(ArgumentParser, metaclass=ParserMeta):
 
         if not flatten:
             name = (
-                f"{proc.__procgroup__.name}/{proc.name}"
-                if getattr(proc, "__procgroup__", None)
+                f"{proc.__meta__['procgroup'].name}/{proc.name}"
+                if proc.__meta__["procgroup"]
                 else proc.name
             )
             # add a namespace argumemnt for this proc
@@ -260,15 +261,26 @@ class Parser(ArgumentParser, metaclass=ParserMeta):
                 "forks",
                 "order",
             ):
-                attrs = PIPEN_ARGS[key]
-                default = getattr(proc, key)
-                if default is not None:
-                    attrs["default"] = default
+                attrs = PIPEN_ARGS[key].copy()
+                proc_default = getattr(proc, key, None)
+                pipen_default = PIPEN_ARGS[key].get("default", None)
+                if proc_default is not None:
+                    attrs["default"] = proc_default
+                elif pipen_default is not None:
+                    attrs["default"] = pipen_default
 
                 self.add_argument(f"--{proc.name}.{key}", **attrs)
 
             for key in ("plugin_opts", "scheduler_opts"):
-                self.add_argument(f"--{proc.name}.{key}", **PIPEN_ARGS[key])
+                self.add_argument(
+                    f"--{proc.name}.{key}",
+                    **{
+                        k: v
+                        for k, v in PIPEN_ARGS[key].items()
+                        if k != "default"
+                    },
+                    default=getattr(proc, key),
+                )
 
     def _add_envs_arguments(
         self,
@@ -288,14 +300,15 @@ class Parser(ArgumentParser, metaclass=ParserMeta):
             if default is not None:
                 vv.attrs["default"] = default
 
+            attrs = self._get_arg_attrs_from_anno(vv.attrs, vv.terms)
             ns.add_argument(
                 f"--{key}.{kk}" if flatten else f"--{proc_name}.{key}.{kk}",
                 help=vv.help or "",
-                **self._get_arg_attrs_from_anno(vv.attrs, vv.terms),
+                **attrs,
             )
 
             # add sub-namespace
-            if vv.attrs.get("action", None) in ("namespace", "ns"):
+            if attrs.get("action", None) in ("namespace", "ns"):
                 self._add_envs_arguments(
                     ns=ns,
                     anno=vv.terms,
